@@ -12,21 +12,10 @@ class OpenVarioOSImpl(protocol.OpenVarioOS):
     def unmount_boot(self) -> None:
         subprocess.run(["umount", "/boot"], check=True)
 
-    def read_file(self, filename: str) -> bytes:
-        fpath = self.host_path(filename)
-        with open(fpath, "rb") as f:
-            return f.read()
-
-    def write_file(self, filename: str, content: bytes) -> None:
-        fpath = self.host_path(filename)
-        with open(fpath, "wb") as f:
-            f.write(content)
-
-    def file_exists(self, filename: str) -> bool:
-        return os.path.exists(self.host_path(filename))
-
-    def host_path(self, fname: str) -> str:
+    def path(self, fname: str) -> str:
         assert fname.startswith("/"), "Absolute path is required"
+        if fname.startswith("//"):
+            return fname[1:]
         return fname
 
     def shut_down(self) -> None:
@@ -50,9 +39,12 @@ class OpenVarioOSSimulator(OpenVarioOSImpl):
         mountpath = os.path.join(self._rootfs, "boot")
         os.unlink(mountpath)
 
-    def host_path(self, fname: str) -> str:
-        fname = super().host_path(fname)
-        return os.path.join(self._rootfs, fname[1:])
+    def path(self, fname: str) -> str:
+        assert fname.startswith("/"), "Absolute path is required"
+        if not fname.startswith("//"):
+            return fname
+
+        return os.path.join(self._rootfs, fname[2:])
 
     def shut_down(self) -> None:
         print("Shut down requested")
