@@ -1,4 +1,4 @@
-from typing import Sequence, Dict
+from typing import Sequence, Dict, List
 import subprocess
 import os
 
@@ -20,8 +20,8 @@ class XCSoarExtension(protocol.Extension):
 
     def _init_settings(self) -> None:
         config = self.shell.settings
-        config.setdefault("xcsoar.binary", "/opt/XCSoar/bin/xcsoar")
-        config.setdefault("xcsoar.home", "/home/root/.xcsoar")
+        config.setdefault("xcsoar.binary", "//opt/XCSoar/bin/xcsoar")
+        config.setdefault("xcsoar.home", "//home/root/.xcsoar")
 
 
 class XCSoarApp(protocol.App):
@@ -69,10 +69,10 @@ class XCSoarApp(protocol.App):
         orientation = self.shell.settings.getstrict("core.screen_orientation", str)
         xcsoar_orient = orient_map[orientation]
 
-        prf_fname = self._find_xcsoar_profile()
-        prf = XCSoarProfile(self.shell.os, prf_fname)
-        prf.set_orientation(xcsoar_orient)
-        prf.save()
+        for prf_fname in self._find_xcsoar_profiles():
+            prf = XCSoarProfile(prf_fname)
+            prf.set_orientation(xcsoar_orient)
+            prf.save()
 
     def _prep_environment(self) -> Dict[str, str]:
         env = os.environ.copy()
@@ -85,19 +85,19 @@ class XCSoarApp(protocol.App):
 
     def _make_commandline(self) -> Sequence[str]:
         os = self.shell.os
-        binary = os.host_path(self.shell.settings.getstrict("xcsoar.binary", str))
+        binary = os.path(self.shell.settings.getstrict("xcsoar.binary", str))
         return [binary, "-fly"]
 
-    def _find_xcsoar_profile(self) -> str:
+    def _find_xcsoar_profiles(self) -> List[str]:
         xcs_home = self.shell.settings.getstrict("xcsoar.home", str)
+        xcs_home = self.shell.os.path(xcs_home)
 
-        profiles = ["openvario.prf", "default.prf"]
-        for fname in profiles:
-            prf_fname = os.path.join(xcs_home, fname)
-            if self.shell.os.file_exists(prf_fname):
-                return prf_fname
+        profiles = []
+        for fname in os.listdir(xcs_home):
+            if fname.endswith(".prf"):
+                profiles.append(os.path.join(xcs_home, fname))
 
-        raise RuntimeError(f"Cannot find XCSoar profile in {xcs_home}")
+        return profiles
 
 
 class AppOutputActivity(protocol.Activity):
@@ -112,27 +112,35 @@ class AppOutputActivity(protocol.Activity):
 
 
 class XCSoarProfile:
-    def __init__(self, os: protocol.OpenVarioOS, filename: str) -> None:
+    def __init__(self, filename: str) -> None:
         self.os = os
         self.filename = filename
+        self._dirty = False
 
-        profile = os.read_file(filename)
-        self.lines = profile.split(b"\n")
+        with open(filename, "r") as f:
+            self.lines = f.readlines()
 
     def save(self) -> None:
-        content = b"\n".join(self.lines)
-        self.os.write_file(self.filename, content)
+        if not self._dirty:
+            return
+        content = "".join(self.lines)
+        with open(self.filename, "w") as f:
+            f.write(content)
 
     def set_orientation(self, orientation: str) -> None:
         self._set_option("DisplayOrientation", orientation)
 
     def _set_option(self, key: str, value: str) -> None:
-        modified_line = f'{key}="{value}"'.encode()
-        bkey = key.encode()
+        modified_line = f'{key}="{value}"\n'
         for n, line in enumerate(self.lines):
-            k, v = line.split(b"=", maxsplit=1)
-            if k == bkey:
+            if "=" not in line:
+                continue
+            k, v = line.split("=", maxsplit=1)
+            v = v.strip('\n"')
+            if k == key:
                 self.lines[n] = modified_line
+                self._dirty = v != value
                 break
         else:
             self.lines.append(modified_line)
+            self._dirty = True
